.g-oauth-provider-list-title{color:#555;border-bottom:1px solid #eee;margin:10px 0;font-size:16px}.g-oauth-value-container{background-color:#f6f6f6;border:1px solid #ddd;margin:10px 0;padding:3px 9px}.g-oauth-value-container .g-oauth-value{margin-left:15px;font-family:monospace;display:inline-block}.g-reg-policy-config-container{background-color:#f7f7f7;border:1px solid #e2e2e2;border-radius:3px;margin-bottom:30px;padding:15px 15px 5px}.g-oauth-container{margin-top:20px}.g-oauth-container .g-oauth-section-header{text-align:center;background-color:#dcd6d6;height:2px;margin-bottom:16px;font-size:12px}.g-oauth-container .g-oauth-section-header-text{color:#878080;background-color:#fff;padding:0 7px;display:inline;position:relative;top:-7px}.g-oauth-button{cursor:pointer;border-radius:3px;width:160px;margin-bottom:10px;margin-right:15px;padding:7px 11px;display:inline-block}.g-oauth-button .g-oauth-button-icon{border-right:1px solid #fff;padding-right:6px;display:inline-block}.g-oauth-button .g-oauth-button-text{text-align:center;width:109px;display:inline-block}.g-oauth-button-google{color:#fff;background-color:#dc4e41;border:1px solid #a82b1f}.g-oauth-button-google:hover{background-color:#cd3426}.g-oauth-button-google .g-oauth-button-icon{border-right-color:#a82b1f}.g-oauth-button-globus{color:#fff;background-color:#2b5693;border:1px solid #1e3c67}.g-oauth-button-globus:hover{background-color:#25497d}.g-oauth-button-globus .g-oauth-button-icon{border-right-color:#1e3c67}.g-oauth-button-github{color:#fff;background-color:#333;border:1px solid #242424}.g-oauth-button-github:hover{background-color:#2b2b2b}.g-oauth-button-github .g-oauth-button-icon{border-right-color:#242424}.g-oauth-button-linkedin{color:#fff;background-color:#0077b5;border:1px solid #00537f}.g-oauth-button-linkedin:hover{background-color:#00659a}.g-oauth-button-linkedin .g-oauth-button-icon{border-right-color:#00537f}.g-oauth-button-bitbucket{color:#fff;background-color:#205081;border:1px solid #16385a}.g-oauth-button-bitbucket:hover{background-color:#1b446e}.g-oauth-button-bitbucket .g-oauth-button-icon{border-right-color:#16385a}.g-oauth-button-microsoft{color:#fff;background-color:#00a1f1;border:1px solid #0071a9}.g-oauth-button-microsoft:hover{background-color:#0089cd}.g-oauth-button-microsoft .g-oauth-button-icon{border-right-color:#0071a9}.g-oauth-button-box{color:#fff;background-color:#0081c6;border:1px solid #005a8b}.g-oauth-button-box:hover{background-color:#006ea8}.g-oauth-button-box .g-oauth-button-icon{border-right-color:#005a8b}.g-oauth-button-cilogon{color:#fff;background-color:#696;border:1px solid #476b47}.g-oauth-button-cilogon:hover{background-color:#578257}.g-oauth-button-cilogon .g-oauth-button-icon{border-right-color:#476b47}
/*$vite$:1*/